| Woods2010 | R Documentation |
Count mortality statistics in randomised controlled trials of treatments for chronic obstructive pulmonary disease (Woods et al. (2010), Table 1).
A data frame with the following columns:
| author | first author / study name |
| treatment | treatment |
| r | number of deaths in treatment arm |
| N | number of patients in treatment arm |
The dataset Woods2010 is identical to dataset
Woods2010 in R package metabook.
Woods BS, Hawkins N, Scott DA (2010): Network meta-analysis on the log-hazard scale, combining count and hazard ratio statistics accounting for multi-arm trials: A tutorial. BMC Medical Research Methodology, 10, 54
pairwise, metabin,
netmeta
head(Woods2010)
# Example using pairwise() and netmeta():
# example(Woods2010, package = "metabook")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.