Learn R Programming

netmeta (version 3.6-0)

merge.pairwise: Merge pairwise object with additional data

Description

Merge pairwise object with additional data, e.g., information on network connectivity.

Usage

# S3 method for pairwise
merge(x, y, all.x = TRUE, ...)

Value

An object of class pairwise.

Arguments

x

An object of class pairwise.

y

A data frame or an object of class netconnection.

all.x

A logical indicating whether to keep all observations from the pairwise object, i.e., also include observations not belonging to a subnetwork due to missing estimates or standard errors.

...

Other arguments (passed on to merge).

See Also

pairwise, netconnection, Woods2010

Examples

Run this code
# Transform data from long arm-based format to contrast-based
# format Argument 'sm' has to be used for odds ratio as summary
# measure; by default the risk ratio is used in the metabin
# function called internally.
#
pw <- pairwise(treatment, event = r, n = N,
  studlab = author, data = Woods2010, sm = "OR",
  append = FALSE)
head(pw)

# Add information on network connectivity
nc <- netconnection(pw)
pw.nc <- merge(pw, nc)
head(pw.nc)

Run the code above in your browser using DataLab