Learn R Programming

netmeta (version 3.1-1)

netgraph.discomb: Network graph for objects of class discomb

Description

This function generates a graph of the evidence network.

Usage

# S3 method for discomb
netgraph(
  x,
  labels = x$trts,
  adj = NULL,
  offset = if (!is.null(adj) && all(unique(adj) == 0.5)) 0 else 0.0175,
  rotate = 0,
  points = !missing(cex.points),
  cex.points = 1,
  ...
)

Arguments

x

An object of class discomb.

labels

An optional vector with treatment labels.

adj

One, two, or three values in [0, 1] (or a vector / matrix with length / number of rows equal to the number of treatments) specifying the x (and optionally y and z) adjustment for treatment labels.

offset

Distance between edges (i.e. treatments) in graph and treatment labels for 2-D plots (value of 0.0175 corresponds to a difference of 1.75% of the range on x- and y-axis).

rotate

A single numeric with value between -180 and 180 specifying the angle to rotate nodes in a circular network.

points

A logical indicating whether points should be printed at nodes (i.e. treatments) of the network graph.

cex.points

Corresponding point size. Can be a vector with length equal to the number of treatments.

...

Additional arguments passed on to netgraph.netmeta.

Author

Guido Schwarzer [email protected], Gerta Rücker [email protected]

Details

The arguments seq and iterate are used internally and cannot be specified by the user.

See Also

discomb, netgraph.netmeta

Examples

Run this code
# Artificial dataset
#
t1 <- c("A + B", "A + C", "A"    , "A"    , "D", "D", "E")
t2 <- c("C"    , "B"    , "B + C", "A + D", "E", "F", "F")
#
mean <- c(4.1, 2.05, 0, 0, 0.1, 0.1, 0.05)
se.mean <- rep(0.1, 7)
#
study <- paste("study", c(1:4, 5, 5, 5))
#
dat <- data.frame(mean, se.mean, t1, t2, study,
                  stringsAsFactors = FALSE)
#
trts <- c("A", "A + B", "A + C", "A + D",
  "B", "B + C", "C", "D", "E", "F")
#
comps <- LETTERS[1:6]

# Use netconnection() to display network information
#
netconnection(t1, t2, study)

dc1 <- discomb(mean, se.mean, t1, t2, study, seq = trts)

netgraph(dc1)

Run the code above in your browser using DataLab