Learn R Programming

netmeta (version 3.7-0)

plot.netrank: Plot treatment ranking(s) of network meta-analyses

Description

Produce an image plot of treatment ranking(s) generated with R function netrank.

Usage

# S3 method for netrank
plot(
  ...,
  name,
  common,
  random,
  seq,
  low = "red",
  mid = "yellow",
  high = "green",
  col = "black",
  main,
  main.size = 14,
  main.col = col,
  main.face = "bold",
  legend = TRUE,
  main.legend = NULL,
  axis.size = 12,
  axis.col = col,
  axis.face = "plain",
  na.value = "grey50",
  angle = 45,
  hjust.x = 1,
  vjust.x = 1,
  hjust.y = 1,
  vjust.y = 0,
  nchar.trts,
  digits = 3,
  digits.mean = 2,
  fixed,
  comb.fixed,
  comb.random,
  warn.deprecated = gs("warn.deprecated")
)

Value

A ggplot2 object or NULL if no ranking was conducted.

Arguments

...

One or more netrank objects.

name

An optional character vector providing descriptive names for the network meta-analysis objects.

common

A logical indicating whether results for the common effects model should be plotted.

random

A logical indicating whether results for the random effects model should be plotted.

seq

A character or numerical vector specifying the sequence of treatments on the x-axis.

low

A character string defining the colour for unfavorable rankings, see scale_fill_gradient2.

mid

A character string defining the colour for average rankings, see scale_fill_gradient2.

high

A character string defining the colour for favorable rankings, see scale_fill_gradient2.

col

Colour of text.

main

Title.

main.size

Font size of title, see element_text.

main.col

Colour of title, see element_text.

main.face

Font face of title, see element_text.

legend

A logical indicating whether a legend should be printed.

main.legend

Title for legend. If missing, the ranking method is used for a single ranking method and "Ranking" for different comparable ranking methods.

axis.size

Font size of axis text, see element_text.

axis.col

Colour of axis text, see element_text.

axis.face

Font face of axis text, see element_text.

na.value

Colour for missing values, see scale_fill_gradient2.

angle

Angle for text on x-axis, see element_text.

hjust.x

A numeric between 0 and 1 with horizontal justification of text on x-axis, see element_text.

vjust.x

A numeric between 0 and 1 with vertical justification of text on x-axis, see element_text.

hjust.y

A numeric between 0 and 1 with horizontal justification of text on y-axis, see element_text.

vjust.y

A numeric between 0 and 1 with vertical justification of text on y-axis, see element_text.

nchar.trts

A numeric defining the minimum number of characters used to create unique treatment names.

digits

Minimal number of significant digits for ranking probabilities, P-scores, and SUCRAs, see print.default.

digits.mean

Minimal number of significant digits for mean or median ranks, see print.default.

fixed

Deprecated argument (replaced by 'common').

comb.fixed

Deprecated argument (replaced by 'common').

comb.random

Deprecated argument (replaced by 'random').

warn.deprecated

A logical indicating whether warnings should be printed if deprecated arguments are used.

Author

Guido Schwarzer guido.schwarzer@uniklinik-freiburg.de, Clément Palpacuer clementpalpacuer@gmail.com

Details

This function produces an image plot of network rankings (Palpacuer et al., 2018, Figure 4). Note, a scatter plot of two network rankings can be generated with plot.netposet.

By default, treatments are ordered by the rankings of the first network meta-analysis object: decreasing for P-scores, SUCRAs, and probabilities of being best, and increasing for mean and median ranks. Argument seq can be used to specify a different treatment order.

Comparable ranking methods can be shown in the same plot: either P-scores, SUCRAs, and probabilities of being best, or mean and median ranks. These two groups of ranking metrics cannot be combined.

References

Palpacuer C, Duprez R, Huneau A, Locher C, Boussageon R, Laviolle B, et al. (2018): Pharmacologically controlled drinking in the treatment of alcohol dependence or alcohol use disorders: a systematic review with direct and network meta-analyses on nalmefene, naltrexone, acamprosate, baclofen and topiramate. Addiction, 113, 220--37

See Also

netrank, netmeta, netposet, hasse, Linde2015

Examples

Run this code
# Examples: example(netrank)

Run the code above in your browser using DataLab