Learn R Programming

netmeta (version 3.6-0)

plot.netsplit: Scatter plot to evaluate local inconsistency in network meta-analysis

Description

Scatter plot to show the difference between direct and indirect evidence in network meta-analysis to assess local inconsistency.

Usage

# S3 method for netsplit
plot(
  x,
  type = "Bland-Altman",
  pooled = ifelse(x$x$random, "random", "common"),
  subset = NULL,
  only.reference = x$only.reference,
  level = x$level.ma,
  vertical = TRUE,
  size.points = NULL,
  points.only.inc = FALSE,
  col = "gray50",
  col.inc = "red",
  labels = TRUE,
  labels.only.inc = FALSE,
  size.labels = 5,
  col.labels = col,
  col.labels.inc = col.inc,
  max_overlap = 10,
  nchar.trts = x$nchar.trts,
  text.pooled,
  main,
  xlab = NULL,
  ylab = NULL,
  xlim = NULL,
  ylim = NULL,
  tag = NULL,
  ...
)

Value

An object of class "plot.netsplit". The object is a list containing the following components:

plot

A ggplot2 object.

data

Data set used to create the plot.

Arguments

x

An object of class netsplit.

type

A character string indicating which figure type is to be used. Either "Bland-Altman" or "Wilson", can be abbreviated. See Details.

pooled

A character string indicating whether results for the common ("common") or random effects model ("random") should be plotted. Can be abbreviated.

subset

An optional logical vector specifying a subset of comparisons to consider (must be of same length as the total number of comparisons).

only.reference

A logical indicating whether only comparisons with the reference group should be considered.

level

The level used to calculate confidence intervals for local local inconsistency.

vertical

A logical indicating whether confidence intervals should be plotted vertically or horizontally; only considered if argument type = "Wilson". The interpretation is the same.

size.points

A single numeric defining the point size. If NULL, point sizes are proportional to the proportion of indirect evidence.

points.only.inc

A logical indicating whether (larger) points should be only shown for comparisons with local inconsistency.

col

Colour of points and confidence intervals.

col.inc

Colour of points and confidence intervals for comparisons with local inconsistency.

labels

A logical value indicating whether to show comparisons labels, or an expression or character vector specifying the labels to use.

labels.only.inc

A logical indicating whether labels are only shown for comparisons with local inconsistency.

size.labels

A single numeric defining the size of comparison labels.

col.labels

Colour of comparison labels.

col.labels.inc

Colour of labels for comparisons with local inconsistency.

max_overlap

An integer specifying the maximum number of overlapping labels allowed in the scatter plot.

nchar.trts

A numeric defining the minimum number of characters used to create unique treatment names in comparisons.

text.pooled

A character string used to describe the statistical model.

main

Main title.

xlab

A label for the x-axis.

ylab

A label for the y-axis.

xlim

The x limits (min, max) of the plot.

ylim

The y limits (min, max) of the plot.

tag

The text for the tag label (see labs).

...

Additional arguments (ignored).

Author

Federico Bonofiglio bonostat@gmx.de, Guido Schwarzer guido.schwarzer@uniklinik-freiburg.de

Details

A scatter plot is drawn in the active graphics window.

By default (argument type = "Bland-Altman"), a variant of the Bland-Altman plot is shown (Bland & Altman, 1995). In this case, the network estimates are shown on the horizontal axis and the difference between direct and indirect effect estimates on the vertical axis. The confidence intervals are those from the differences.

If argument type = "Wilson", a scatter plot with direct effect estimates on the horizontal and indirect estimates on the vertical axis is produced (Wilson et al., 2026). The confidence intervals are calculated from the indirect (argument vertical = TRUE) or direct effect estimates and the standard error of the difference between indirect and direct effect estimates.

For both plot types, the dashed green line corresponds to comparisons with equal direct and indirect effect estimates.

References

Bland JM, Altman DG (1995): Comparing methods of measurement: Why plotting difference against standard method is misleading. The Lancet, 346, 1085--87

Wilson H, Schönstein A, Robson S, Bonofiglio F (2026): A novel approach for visualizing local consistency in network meta-analysis. Research Synthesis Methods, 1--15

See Also

forest.netsplit

Examples

Run this code
# Examples: example(netsplit)

Run the code above in your browser using DataLab