Print and summary method for objects of class netmeta.
# S3 method for netmeta
print(x, sortvar, level=x$level, level.comb=x$level.comb,
comb.fixed=x$comb.fixed, comb.random=x$comb.random,
reference.group=x$reference.group, all.treatments=x$all.treatments,
details=TRUE, ma=TRUE, logscale=FALSE,
digits=max(4, .Options$digits - 3), ...)# S3 method for netmeta
summary(object,
level=object$level, level.comb=object$level.comb,
comb.fixed=object$comb.fixed, comb.random=object$comb.random,
reference.group=object$reference.group, all.treatments=object$all.treatments,
warn=object$warn, ...)
# S3 method for summary.netmeta
print(x, comb.fixed=x$comb.fixed, comb.random=x$comb.random,
reference.group=x$reference.group, all.treatments=x$all.treatments,
logscale=FALSE, header=TRUE, digits=max(3, .Options$digits - 3), ...)
An object of class netmeta or summary.netmeta.
An object of class netmeta.
An optional vector used to sort individual studies
(must be of same length as x$TE).
The level used to calculate confidence intervals for individual studies.
The level used to calculate confidence intervals for pooled estimates.
A logical indicating whether a fixed effect meta-analysis should be conducted.
A logical indicating whether a random effects meta-analysis should be conducted.
Reference group.
A logical or value "NULL". If
TRUE, matrices with all treatment effects, and confidence
limits will be printed.
A logical indicating whether further details for individual studies should be printed.
A logical indicating whether summary results of meta-analysis should be printed.
A logical indicating whether results for summary measures 'RR', 'OR', 'HR', or 'PLN' will be printed on logarithmic scale.
A logical indicating whether information on title of meta-analysis, comparison and outcome should be printed at the beginning of the printout.
Minimal number of significant digits, see print.default.
A logical indicating whether the use of
summary.meta in connection with metacum or
metainf should result in a warning.
Additional arguments.
A list is returned by the function summary.netmeta with the
following elements:
Results for pairwise comparisons (a list with elements TE, seTE, lower, upper, z, p, level, df, studlab, treat1, treat2).
Results for pairwise comparisons based on fixed effect model (a list with elements TE, seTE, lower, upper, z, p, level, df, studlab, treat1, treat2, leverage).
Results for pairwise comparisons based on random effects model (a list with elements TE, seTE, lower, upper, z, p, level, df, studlab, treat1, treat2).
Results for fixed effect model (a list with elements TE, seTE, lower, upper, z, p, level, df).
Results for random effects model (a list with elements TE, seTE, lower, upper, z, p, level, df).
Study labels coerced into a factor with its levels sorted alphabetically.
Number of arms for each study.
Total number of studies.
Total number of pairwise comparisons.
Total number of treatments.
Overall heterogeneity / inconsistency statistic.
Degrees of freedom for test of heterogeneity / inconsistency.
Square-root of between-study variance.
I-squared.
A character string indicating underlying summary measure.
Label for confidence interval.
A logical indicating whether result for fixed effect meta-analysis should be printed.
A logical indicating whether result for random effects meta-analysis should be printed.
The level used to calculate confidence intervals for individual comparisons.
The level used to calculate confidence intervals for pooled estimates.
A character specifying the sequence of treatments.
A logical or value "NULL". If
TRUE, matrices with all treatment effects, and confidence
limits will be printed.
Reference group.
A logical or value "NULL". If
TRUE, matrices with all treatment effects, and confidence
limits will be printed.
Title of meta-analysis / systematic review.
Function call.
Version of R package netmeta used to create object.
# NOT RUN {
data(Senn2013)
#
# Fixed effect model (default)
#
net1 <- netmeta(TE, seTE, treat1, treat2, studlab,
data=Senn2013, sm="MD")
print(net1, ref="plac", digits=3)
summary(net1)
#
# Random effects model
#
net2 <- netmeta(TE, seTE, treat1, treat2, studlab,
data=Senn2013, sm="MD", comb.random=TRUE)
print(net2, ref="plac", digits=3)
summary(net2)
# }
Run the code above in your browser using DataLab