# \donttest{
pw <- pairwise(studlab = study, treat = treatment,
n = n, mean = mean, sd = sd, data = Senn2013,
varnames = c("MD", "seMD"))
#
nma <- netmeta(pw)
# 'Comparison-adjusted' radial plot not created as argument 'order'
# is missing
#
try(radial(nma))
# Only show comparisons with placebo
#
radial(nma, order = "pl")
# Add result for Egger test of funnel plot asymmetry
#
radial(nma, order = "pl", method.bias = "Egger",
digits.pval = 2)
# (Non-sensical) alphabetic order of treatments with placebo as
# last treatment
#
ord <- c("a", "b", "me", "mi", "pi", "r", "si", "su", "v", "pl")
radial(nma, order = ord)
# Add results for tests of funnel plot asymmetry and use different
# plotting symbols and colours
#
radial(nma, order = ord,
pch = rep(c(15:18, 1), 3), col = 1:3,
method.bias = c("Egger", "Begg", "Thompson"), digits.pval = 2)
# Same results for tests of funnel plot asymmetry using reversed
# order of treatments
#
radial(nma, order = rev(ord),
pch = rep(c(15:18, 1), 3), col = 1:3,
method.bias = c("Egger", "Begg", "Thompson"), digits.pval = 2)
# Calculate tests for funnel plot asymmetry
#
f1 <- radial(nma, order = ord)
#
metabias(metagen(TE.adj, seTE, data = f1))
metabias(metagen(TE.adj, seTE, data = f1), method = "Begg")
metabias(metagen(TE.adj, seTE, data = f1), method = "Thompson")
# }
Run the code above in your browser using DataLab