merge.pairwise: Merge pairwise object with additional data

View source: R/merge.pairwise.R

merge.pairwiseR Documentation

Merge pairwise object with additional data

Description

Merge pairwise object with additional data, e.g., information on network connectivity.

Usage

## S3 method for class 'pairwise'
merge(x, y, all.x = TRUE, ...)

Arguments

x

An object of class pairwise.

y

A data frame or an object of class netconnection.

all.x

A logical indicating whether to keep all observations from the pairwise object, i.e., also include observations not belonging to a subnetwork due to missing estimates or standard errors.

...

Other arguments (passed on to merge).

Value

An object of class pairwise.

Author(s)

Guido Schwarzer guido.schwarzer@uniklinik-freiburg.de

See Also

pairwise, netconnection, Woods2010

Examples

# Transform data from long arm-based format to contrast-based
# format Argument 'sm' has to be used for odds ratio as summary
# measure; by default the risk ratio is used in the metabin
# function called internally.
#
pw <- pairwise(treatment, event = r, n = N,
  studlab = author, data = Woods2010, sm = "OR",
  append = FALSE)
head(pw)

# Add information on network connectivity
nc <- netconnection(pw)
pw.nc <- merge(pw, nc)
head(pw.nc)


netmeta documentation built on April 11, 2026, 9:06 a.m.