# Transform data from long arm-based format to contrast-based
# format Argument 'sm' has to be used for odds ratio as summary
# measure; by default the risk ratio is used in the metabin
# function called internally.
#
pw <- pairwise(treatment, event = r, n = N,
studlab = author, data = Woods2010, sm = "OR",
append = FALSE)
head(pw)
# Add information on network connectivity
nc <- netconnection(pw)
pw.nc <- merge(pw, nc)
head(pw.nc)
Run the code above in your browser using DataLab