This function calculates the probabilities of each treatment being at each possible rank and the SUCRAs (Surface Under the Cumulative RAnking curve) from a sample of treatment estimates in network meta-analysis.
# S3 method for default
rankogram(
x,
pooled = "unspecified",
small.values = "desirable",
cumulative.rankprob = FALSE,
keep.samples = FALSE,
nchar.trts = gs("nchar.trts"),
...
)An object of class rankogram with corresponding print
and plot function. The object is a list containing the
following components:
As defined above.
Logical values for common or random effects model.
As defined above.
As defined above.
As defined above.
Function call.
Version of R package netmeta used to create object.
The following components are available if argument pooled = "common":
SUCRA values for the common effects model.
Numeric matrix giving the probability of each treatment being at each possible rank for the common effects model.
Numeric matrix giving the cumulative ranking probabilities for the common effects model.
Mean ranks for the common effects model.
Median ranks for the common effects model.
Samples for the common effects model
(if keep.samples = TRUE).
The following components are available if argument pooled != "common":
SUCRA values for the random effects model.
Numeric matrix giving the probability of each treatment being at each possible rank for the random effects model.
Numeric matrix giving the cumulative ranking probabilities for the random effects model.
Mean ranks for the random effects model.
Median ranks for the random effects model.
Samples for the random effects model
(if keep.samples = TRUE).
A matrix or data frame with treatment effects in columns and samples in rows.
A character string indicating whether samples come from
a common ("common"), random effects ("random"), or
"unspecified" model, can be abbreviated.
An optional character string specifying whether small
treatment effects indicate a beneficial ("desirable") or
harmful ("undesirable") effect, can be abbreviated.
A logical indicating whether cumulative ranking probabilities should be printed.
A logical indicating whether to keep the samples, i.e.,
input to argument x.
A numeric defining the minimum number of characters used to create unique treatment names.
Additional arguments (ignored).
Theodoros Papakonstantinou dev@tpapak.com, Guido Schwarzer guido.schwarzer@uniklinik-freiburg.de
We derive a matrix showing the probability of each treatment being at each possible rank. To this aim, we use samples and summarise them using the ranking metric SUCRAs (Surface Under the Cumulative RAnking curve).
The matrix / data frame in argument x must contain the sampled
effects for each treatment.
Salanti G, Ades AE, Ioannidis JP (2011): Graphical methods and numerical summaries for presenting results from multiple-treatment meta-analysis: an overview and tutorial. Journal of Clinical Epidemiology, 64, 163--71
netmeta, netrank,
plot.rankogram,
Woods2010
pw <- pairwise(treatment, event = r, n = N, studlab = author,
data = Woods2010, sm = "OR")
nma <- netmeta(pw, small.values = "desirable")
set.seed(1909) # get reproducible results
rnk <- rankogram(nma, common = FALSE, nsim = 10, # reduce runtime
keep.samples = TRUE)
rnk
rankogram(rnk$samples.random)
Run the code above in your browser using DataLab